[Nvda-dev] commit r2439 - in trunk: . source

NVDA Subversion svn at nvda-project.org
Wed Oct 22 09:26:48 UTC 2008


Author: bzr
Date: Wed Oct 22 09:26:48 2008
New Revision: 2439

Log:
	* setup.py: Copy brailleDisplayDrivers to the dist directory.
	* generate.py: Compile byte code for brailleDisplayDrivers.


Modified:
   trunk/   (props changed)
   trunk/source/generate.py
   trunk/source/setup.py

Modified: trunk/source/generate.py
==============================================================================
--- trunk/source/setup.py	(original)
+++ trunk/source/setup.py	Wed Oct 22 09:26:48 2008
@@ -70,5 +70,5 @@
 		("waves", glob("waves/*.wav")),
 		("images", glob("images/*.ico")),
 		("speechdicts", glob("speechdicts/*.dic")),
-	] + getLocaleDataFiles()+getRecursiveDataFiles('documentation','../user_docs')+getRecursiveDataFiles('synthDrivers','synthDrivers'),
+	] + getLocaleDataFiles()+getRecursiveDataFiles('documentation','../user_docs')+getRecursiveDataFiles('synthDrivers','synthDrivers')+getRecursiveDataFiles('brailleDisplayDrivers','brailleDisplayDrivers'),
 )



More information about the Nvda-dev mailing list
--- trunk/source/generate.py	(original)
+++ trunk/source/generate.py	Wed Oct 22 09:26:48 2008
@@ -8,7 +8,7 @@
 This script:
 * Generates Python code for COM interfaces to avoid doing this at runtime;
 * Compiles source language files into binary form for use by NVDA;
 * Compiles appModules and synthDrivers into Python byte code to eliminate the need to do this on launch.
 This should be run prior to executing NVDA from a clean source tree for the first time and before building a binary distribution with py2exe.
 """
 
@@ -33,7 +33,7 @@
 	("SAPI 5", comtypes.client.CreateObject, "Sapi.SPVoice"),
 	("SAPI 4", comtypes.client.CreateObject, "ActiveVoice.ActiveVoice"),
 )
-COMPILE_DIRS = ("appModules", "synthDrivers")
+COMPILE_DIRS = ("appModules", "synthDrivers", "brailleDisplayDrivers")
 
 def main():
 	print "COM interfaces:"
@@ -8,7 +8,7 @@
 * Generates Python code for COM interfaces to avoid doing this at runtime;
 * Compiles source language files into binary form for use by NVDA;
-* Compiles appModules and synthDrivers into Python byte code to eliminate the need to do this on launch.
+* Compiles appModules, synthDrivers and brailleDisplayDrivers into Python byte code to eliminate the need to do this on launch.
 This should be run prior to executing NVDA from a clean source tree for the first time and before building a binary distribution with py2exe.
 """

Modified: trunk/source/setup.py
==============================================================================